---
title: ArmaRAMDb - Hash Delete
icon: mdi:file-text-outline
excerpt: Remove the current client's hash table from database.
---

# ramdb_db_fnc_hashDelete

## Description
Removes the hash table associated with the current client/player from the database. Unlike `hashDeleteId`, this function automatically retrieves the appropriate hash ID based on the caller's identity, making it more convenient for removing the current client's hash data. This is useful for cleanup operations when a player disconnects or when resetting a client's stored data.

## Syntax
```sqf
[] call ramdb_db_fnc_hashDelete
```

## Parameters
None. This function automatically determines the hash ID based on the calling client.

## Return Value
None. The operation runs synchronously to delete the hash table for the current client.

## Examples
### Delete the current client's hash table:
```sqf
[] call ramdb_db_fnc_hashDelete;
```

### Delete a client's hash table from the server:
```sqf
[] remoteExecCall ["ramdb_db_fnc_hashDelete", 2, false];
```

## Notes
- This function only removes the hash table for the current client/player, not all hash tables
- It's similar to `hashDeleteId` but automatically determines the appropriate ID
- Cannot be undone unless you have a backup
- Should be used during player disconnection or when resetting a player's data
- Useful for cleanup operations to prevent data buildup from disconnected players
- More convenient than `hashDeleteId` when you want to remove the calling client's data
- All operations are logged for debugging purposes

## Related Functions
- `ramdb_db_fnc_hashDeleteId`: Removes a specific hash ID (when you need to specify the ID)
- `ramdb_db_fnc_hashDeleteField`: Removes a specific field from a hash
- `ramdb_db_fnc_hashSet`: Sets a value in the hash table
- `ramdb_db_fnc_hashGet`: Retrieves a value from the hash table

## Links

[Hash Delete](hashDelete) |
[Hash Delete Field](hashDeleteField) |
[Hash Delete ID](hashDeleteId) |
[Hash Get](hashGet) |
[Hash Get All](hashGetAll) |
[Hash Get All ID](hashGetAllId) |
[Hash Get ID](hashGetId) |
[Hash Set](hashSet) |
[Hash Set Bulk](hashSetBulk) |
[Hash Set ID](hashSetId) |
[Hash Set ID Bulk](hashSetIdBulk)
